ZInverseHarmonicMeanRank
========================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: ZInverseHarmonicMeanRank
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ZInverseHarmonicMeanRank.name
      ~ZInverseHarmonicMeanRank.synonyms

   .. rubric:: Attributes Documentation

   .. autoattribute:: name
   .. autoattribute:: synonyms
